==> WinBinder-0.32.108.tgz: Code/ToDo/todo.rc.php <==
<?php

// Control identifiers

if(!defined("IDD_DIALOG1001")) define("IDD_DIALOG1001", 2001);
if(!defined("ID_ITEMLIST")) define("ID_ITEMLIST", 2106);
if(!defined("ID_MOVEUP")) define("ID_MOVEUP", 2008);
if(!defined("ID_MOVEDOWN")) define("ID_MOVEDOWN", 2009);
if(!defined("ID_TREE")) define("ID_TREE", 2112);
if(!defined("ID_DESCRIPTION")) define("ID_DESCRIPTION", 2114);
if(!defined("IDC_SHAPE2119")) define("IDC_SHAPE2119", 2119);
if(!defined("ID_FILTERTYPE")) define("ID_FILTERTYPE", 2124);
if(!defined("ID_FILTERTEXT")) define("ID_FILTERTEXT", 2121);
if(!defined("ID_FILTER")) define("ID_FILTER", 2123);
if(!defined("ID_FIELD")) define("ID_FIELD", 2126);
if(!defined("ID_FILTERPRESETS")) define("ID_FILTERPRESETS", 2128);

// Create window

$mainwin = wb_create_window(NULL, 100, "WinBinder: To Do", WBC_CENTER, WBC_CENTER, 632, 508, WBC_INVISIBLE | WBC_NOTIFY, 2);

// Insert controls

wb_create_control($mainwin, ListView, "", 212, 62, 382, 282, ID_ITEMLIST, WBC_VISIBLE | WBC_ENABLED | WBC_SORT | WBC_LINES);
$_tmp_ctrl_ = wb_create_control($mainwin, PushButton, "up_arrow.bmp", 599, 62, 21, 21, ID_MOVEUP, WBC_VISIBLE | WBC_ENABLED);
wb_set_image($_tmp_ctrl_, '../res/up_arrow.bmp', 0, GREEN); unset($_tmp_ctrl_);
$_tmp_ctrl_ = wb_create_control($mainwin, PushButton, "dn_arrow.bmp", 599, 86, 21, 21, ID_MOVEDOWN, WBC_VISIBLE | WBC_ENABLED);
wb_set_image($_tmp_ctrl_, '../res/dn_arrow.bmp', 0, GREEN); unset($_tmp_ctrl_);
wb_create_control($mainwin, TreeView, "", 4, 36, 206, 403, ID_TREE, WBC_VISIBLE | WBC_ENABLED);
wb_create_control($mainwin, EditBox, "(Description)", 215, 354, 379, 83, ID_DESCRIPTION, WBC_VISIBLE | WBC_ENABLED | WBC_LINES | WBC_READONLY);
wb_create_control($mainwin, Frame, "", 0, 27, 620, 3, IDC_SHAPE2119, WBC_VISIBLE | WBC_ENABLED);
wb_create_control($mainwin, EditBox, "", 457, 36, 113, 21, ID_FILTERTEXT, WBC_VISIBLE | WBC_ENABLED);
wb_create_control($mainwin, PushButton, "F&ilter", 575, 36, 45, 21, ID_FILTER, WBC_VISIBLE | WBC_ENABLED);
wb_create_control($mainwin, ComboBox, "", 457, 36, 113, 196, ID_FILTERPRESETS, WBC_VISIBLE | WBC_ENABLED);
wb_create_control($mainwin, ComboBox, "", 312, 36, 138, 147, ID_FILTERTYPE, WBC_VISIBLE | WBC_ENABLED);
wb_create_control($mainwin, ComboBox, "", 214, 36, 93, 147, ID_FIELD, WBC_VISIBLE | WBC_ENABLED);

// End controls

?>

==> WinBinder-0.33.113.tgz: Code/ToDo/todo.rc.php <==
<?php

// Control identifiers

if(!defined("IDD_DIALOG1001")) define("IDD_DIALOG1001", 2001);
if(!defined("ID_ITEMLIST")) define("ID_ITEMLIST", 2106);
if(!defined("ID_MOVEUP")) define("ID_MOVEUP", 2008);
if(!defined("ID_MOVEDOWN")) define("ID_MOVEDOWN", 2009);
if(!defined("ID_TREE")) define("ID_TREE", 2112);
if(!defined("ID_DESCRIPTION")) define("ID_DESCRIPTION", 2114);
if(!defined("IDC_SHAPE2119")) define("IDC_SHAPE2119", 2119);
if(!defined("ID_FILTERTYPE")) define("ID_FILTERTYPE", 2124);
if(!defined("ID_FILTERTEXT")) define("ID_FILTERTEXT", 2121);
if(!defined("ID_FILTER")) define("ID_FILTER", 2123);
if(!defined("ID_FIELD")) define("ID_FIELD", 2126);
if(!defined("ID_FILTERPRESETS")) define("ID_FILTERPRESETS", 2128);

// Create window

$mainwin = wb_create_window(NULL, 100, "WinBinder: To Do", WBC_CENTER, WBC_CENTER, 632, 508, WBC_INVISIBLE | WBC_NOTIFY, 32);

// Insert controls

wb_create_control($mainwin, ListView, "", 212, 62, 382, 282, ID_ITEMLIST, WBC_VISIBLE | WBC_ENABLED | WBC_SORT | WBC_LINES);
$_tmp_ctrl_ = wb_create_control($mainwin, PushButton, "up_arrow.bmp", 599, 62, 21, 21, ID_MOVEUP, WBC_VISIBLE | WBC_ENABLED);
wb_set_image($_tmp_ctrl_, '../res/up_arrow.bmp', 0, GREEN); unset($_tmp_ctrl_);
$_tmp_ctrl_ = wb_create_control($mainwin, PushButton, "dn_arrow.bmp", 599, 86, 21, 21, ID_MOVEDOWN, WBC_VISIBLE | WBC_ENABLED);
wb_set_image($_tmp_ctrl_, '../res/dn_arrow.bmp', 0, GREEN); unset($_tmp_ctrl_);
wb_create_control($mainwin, TreeView, "", 4, 36, 206, 403, ID_TREE, WBC_VISIBLE | WBC_ENABLED);
wb_create_control($mainwin, EditBox, "(Description)", 215, 354, 379, 83, ID_DESCRIPTION, WBC_VISIBLE | WBC_ENABLED | WBC_LINES | WBC_READONLY);
wb_create_control($mainwin, Frame, "", 0, 27, 620, 3, IDC_SHAPE2119, WBC_VISIBLE | WBC_ENABLED);
wb_create_control($mainwin, EditBox, "", 457, 36, 113, 21, ID_FILTERTEXT, WBC_VISIBLE | WBC_ENABLED);
wb_create_control($mainwin, PushButton, "Fi&lter", 575, 36, 45, 21, ID_FILTER, WBC_VISIBLE | WBC_ENABLED);
wb_create_control($mainwin, ComboBox, "", 457, 36, 113, 196, ID_FILTERPRESETS, WBC_VISIBLE | WBC_ENABLED);
wb_create_control($mainwin, ComboBox, "", 312, 36, 138, 147, ID_FILTERTYPE, WBC_VISIBLE | WBC_ENABLED);
wb_create_control($mainwin, ComboBox, "", 214, 36, 93, 147, ID_FIELD, WBC_VISIBLE | WBC_ENABLED);

// End controls

?>
